#ifndef XMALLOC_H
#define XMALLOC_H

#include <stdio.h>
#include <stdlib.h>

/* 関数プロトタイプ */
static inline void * xmalloc(const size_t size) ;

/*******************************************************************************
 * mallocのラッパー関数
*******************************************************************************/
static inline void * xmalloc(const size_t size)
{
	void *p = malloc(size);

	if(!p)
	{
		perror("malloc");
		exit(EXIT_FAILURE);
	}

	return p;
}

#endif
